@@ -7,6 +7,8 @@ import os, zipfile, requests, io
 import tempfile, shutil
 import platform
 from pathlib import Path
+import sys
+from typing import Optional
 
 from . import utils, static, VERSION, CORE_COMMIT, core
 from .project import Target, Project
@@ -43,14 +45,6 @@ def main(ctx,targets):
     Use the `--help` option on any CLI command to learn more, for example,
     `pretext build --help`.
     """
-    # set verbosity:
-    if log.level == 10:
-        verbosity = 2
-    elif log.level == 50:
-        verbosity = 0
-    else:
-        verbosity = 1
-    core.set_verbosity(verbosity)
     if targets:
         Project().print_target_names()
         return
@@ -58,6 +52,8 @@ def main(ctx,targets):
         # create file handler which logs even debug messages
         fh = logging.FileHandler(utils.project_path()/'cli.log', mode='w')
         fh.setLevel(logging.DEBUG)
+        file_log_format = logging.Formatter('%(levelname)-8s:  %(message)s')
+        fh.setFormatter(file_log_format)
         log.addHandler(fh)
         # output info
         log.info(f"PreTeXt project found in `{utils.project_path()}`.")
@@ -65,10 +61,11 @@ def main(ctx,targets):
         os.chdir(utils.project_path())
         if utils.requirements_version() is None:
             log.warning("Project's CLI version could not be detected from `requirements.txt`.")
+            log.warning("Try `pretext init --refresh` to produce a compatible file.")
         elif utils.requirements_version() != VERSION:
             log.warning(f"Using CLI version {VERSION} but project's `requirements.txt`")
             log.warning(f"is configured to use {utils.requirements_version()}. Consider either installing")
-            log.warning(f"CLI version {utils.requirements_version()} or updating `requirements.txt` to {VERSION}.")
+            log.warning(f"CLI version {utils.requirements_version()} or changing `requirements.txt` to match {VERSION}.")
         else:
             log.debug(f"CLI version {VERSION} matches requirements.txt {utils.requirements_version()}.")
     else:
@@ -224,40 +221,35 @@ def init(refresh):
     log.info(f"Success! Open project.ptx to edit your project manifest.")
     log.info(f"Edit your <target/>s to point to the location of your PreTeXt source files.")
 
+ASSETS = ['ALL', 'webwork', 'latex-image', 'sageplot', 'asymptote', 'interactive', 'youtube', 'codelens']
 
 # pretext build
 @main.command(short_help="Build specified target", 
     context_settings=CONTEXT_SETTINGS)
 @click.argument('target', required=False)
-@click.option('-f', '--format', type=click.Choice(['html','latex','pdf']),
-              help='Output format to build.')
-@click.option('-i', '--input', 'source', type=click.Path(),
-              help='Path to main *.ptx file')
-@click.option('-o', '--output', type=click.Path(),
-              help='Directory to build files into')
-@click.option('-p', '--publication', type=click.Path(), default=None,
-              help="Path to publication *.ptx file")
-@click.option('-x', '--xsl', type=click.Path(), default=None,
-              help="Path to custom xsl file")
-@click.option('--stringparam', nargs=2, multiple=True, help="""
-              Define a stringparam to use during processing.
-              Usage: pretext build --stringparam foo bar --stringparam baz woo
-              """)
 @click.option('--clean', is_flag=True, help="Destroy output's target directory before build to clean up previously built files")
 @click.option(
-    '-g', '--generate', is_flag=True, 
-    help='Generate assets in default formats before build')
-@click.option(
-    '-a', '--assets', default="ALL",
-    type=click.Choice(['ALL', 'webwork', 'latex-image', 'sageplot', 'asymptote', 'interactive', 'youtube', 'codelens'], case_sensitive=False), 
-    help='If generating, choose to generate ALL or specific assets')
+    '-g', '--generate', is_flag=False, flag_value="ALL", default=None,
+    type=click.Choice(ASSETS, case_sensitive=False), 
+    help='If generating, specific assets that should be generated')
 @click.option('-d', '--diagrams', is_flag=True, help='OBSOLETE. Use --generate')
 @click.option('-w', '--webwork', is_flag=True, default=False, help='OBSOLETE. Use --generate')
-def build(target, format, source, output, stringparam, xsl, publication, clean, generate, assets,
+@click.option('-f', '--format', type=click.Choice(['html','latex','pdf']),
+              help='OBSOLETE. Update your project.ptx target instead.')
+@click.option('-i', '--input', 'source', type=click.Path(),
+              help='OBSOLETE. Update your project.ptx target instead.')
+@click.option('-o', '--output', type=click.Path(),
+              help='OBSOLETE. Update your project.ptx target instead.')
+@click.option('-p', '--publication', type=click.Path(), default=None,
+              help='OBSOLETE. Update your project.ptx target instead.')
+@click.option('-x', '--xsl', type=click.Path(), default=None,
+              help='OBSOLETE. Update your project.ptx target instead.')
+@click.option('--stringparam', nargs=2, multiple=True,
+              help='OBSOLETE. Update your project.ptx target instead.')
+def build(target, format, source, output, stringparam, xsl, publication, clean, generate,
     webwork, diagrams,):
     """
-    Process [TARGET] into format specified by project.ptx.
-    Also accepts manual command-line options.
+    Build [TARGET] according to settings specified by project.ptx.
 
     If using certain elements (webwork, latex-image, etc.) then
     using `--generate` may be necessary for a successful build. Generated
@@ -270,9 +262,14 @@ def build(target, format, source, output, stringparam, xsl, publication, clean,
     consult the PreTeXt Guide: https://pretextbook.org/documentation.html
     """
     if diagrams or webwork:
-        log.error("Command used an asset option that is now obsolete.")
-        log.error("Assets are now generated with `pretext generate` or `pretext build -g`.")
-        log.error("Cancelling build. Check `--help` for details.")
+        log.critical("Command used an asset option that is now obsolete.")
+        log.critical("Assets are now generated with `pretext generate` or `pretext build -g`.")
+        log.critical("Cancelling build. Check `--help` for details.")
+        return
+    if source or output or format or len(stringparam)>0 or xsl:
+        log.critical("Customizing target settings on the command line is no longer supported")
+        log.critical("Edit your `project.ptx` instead.")
+        log.critical("Cancelling build. Check `--help` for details.")
         return
     target_name = target
     # set up stringparams as dictionary:
@@ -281,34 +278,24 @@ def build(target, format, source, output, stringparam, xsl, publication, clean,
     else:
         stringparams = None
     if utils.project_path() is None:
-        log.warning(f"No project.ptx manifest was found. Run `pretext init` to generate one.")
-        log.warning("Continuing using commandline arguments.")
-        if publication is None:
-              pass
-        target = Target(name=format,format=format,source=source,output_dir=output,
-                        publication=publication,stringparams=stringparams)
-        project = Project(targets=[target])
-    else:
-        project = Project()
-        if target_name is None:
-            log.info(f"Since no build target was supplied, the first target of the "+
-                     "project.ptx manifest will be built.")
-        target = project.target(name=target_name)
-        if target is None:
-            log.critical("Build target could not be found in project.ptx manifest.")
-            log.critical("Exiting without completing task.")
-            return
-        #overwrite target with commandline arguments, update project accordingly
-        target = Target(xml_element=target.xml_element(),
-                        format=format,source=source,output_dir=output,
-                        publication=publication,stringparams=stringparams,xsl_path=xsl)
-        project = Project(xml_element=project.xml_element(),targets=[target])
-    if generate and assets=='ALL':
+        log.critical("No project.ptx manifest was found.")
+        log.critical("Use `pretext new` to create a new project or `pretext init` to update existing project for use with the CLI.")
+        return
+    project = Project()
+    if target_name is None:
+        log.info(f"Since no build target was supplied, the first target of the "+
+                    "project.ptx manifest will be built.")
+    target = project.target(name=target_name)
+    if target is None:
+        log.critical("Build target could not be found in project.ptx manifest.")
+        log.critical("Exiting without completing task.")
+        return
+    if generate=='ALL':
         log.info("Genearting all assets in default formats.")
         project.generate(target_name)
-    elif generate:
-        log.warning(f"Generating only {assets} assets.")
-        project.generate(target_name,asset_list=[assets])
+    elif generate is not None:
+        log.warning(f"Generating only {generate} assets.")
+        project.generate(target_name,asset_list=[generate])
     else:
         log.warning("Assets like latex-images will not be regenerated for this build")
         log.warning("(previously generated assets will be used if they exist).")
@@ -318,16 +305,17 @@ def build(target, format, source, output, stringparam, xsl, publication, clean,
 # pretext generate
 @main.command(short_help="Generate assets for specified target", 
     context_settings=CONTEXT_SETTINGS)
-@click.argument('target', required=False)
+@click.argument('assets', default="ALL",
+    type=click.Choice(ASSETS, case_sensitive=False))
 @click.option(
-    '-a', '--assets', default="ALL",
-    type=click.Choice(['ALL', 'webwork', 'latex-image', 'sageplot', 'asymptote', 'interactive', 'youtube', 'codelens'], case_sensitive=False), 
-    help='Generate ALL or specific assets')
+    '-t', '--target', type=click.STRING, help="Name of target to generate assets for (uses default target if not specified).")
+@click.option(
+    '-x', '--xmlid', type=click.STRING, help="xml:id of element to be generated.")
 @click.option('--all-formats', is_flag=True, default=False, 
     help='Generate all possible asset formats rather than the defaults for the given target.')
-def generate(target, assets, all_formats):
+def generate(assets:str, target:Optional[str], all_formats:bool, xmlid:Optional[str]):
     """
-    Generate assets for the specified target. Asset "generation" is typically
+    Generate specified (or all) assets for the default target. Asset "generation" is typically
     slower and performed less frequently than "building" a project, but is
     required for many PreTeXt features such as latex-image.
 
@@ -340,10 +328,10 @@ def generate(target, assets, all_formats):
     target_name = target
     if assets == 'ALL':
         log.info("Genearting all assets in default formats.")
-        project.generate(target_name)
+        project.generate(target_name,xmlid=xmlid)
     else:
         log.info(f"Generating only {assets} assets.")
-        project.generate(target_name,asset_list=[assets])
+        project.generate(target_name,asset_list=[assets],xmlid=xmlid)
 
 
 # pretext view
@@ -364,8 +352,7 @@ def generate(target, assets, all_formats):
 @click.option(
     '-p',
     '--port',
-    default=8000,
-    show_default=True,
+    type=click.INT,
     help="""
     Choose which port to use for the local server.
     """)
@@ -387,26 +374,32 @@ def generate(target, assets, all_formats):
 @click.option('-b', '--build', is_flag=True, help="""
     Run a build before starting server.
     """)
-@click.option('-g', '--generate', is_flag=True, help="""
-    Generate all assets before starting server.
-    """)
-def view(target,access,port,directory,watch,build,generate):
+@click.option(
+    '-g', '--generate', is_flag=False, flag_value="ALL", default=None,
+    type=click.Choice(ASSETS, case_sensitive=False), 
+    help='If generating, specific assets that should be generated')
+def view(target:str,access:str,port:Optional[int],directory:str,watch:bool,build:bool,generate:Optional[str]):
     """
     Starts a local server to preview built PreTeXt documents in your browser.
     TARGET is the name of the <target/> defined in `project.ptx`.
     """
     if directory is not None:
-        utils.run_server(directory,access,port)
+        port = port or 8000
+        utils.run_server(Path(directory),access,port)
         return
     target_name=target
     project = Project()
     target = project.target(name=target_name)
+    port = port or target.port()
     if target is None:
         log.error(f"Target `{target_name}` could not be found.")
         return
-    if generate:
+    if generate == "ALL":
         log.info("Generating all assets in default formats.")
         project.generate(target_name)
+    elif generate is not None:
+        log.warning(f"Generating only {generate} assets.")
+        project.generate(target_name,asset_list=[generate])
     if build or watch:
         log.info("Building target.")
         project.build(target_name)
